#!/usr/bin/env python
# -*- coding: utf-8 -*-

import time

from db_paribhasha import credentials
from db_paribhasha.error_handler import OperationNotPerformedError
from db_paribhasha.dynamo.dynamo_helpers import save_dynamo_object
from db_paribhasha.dynamo.studio_visualisation_logs.studio_visualisation_logs_model import StudioVisualisationLogs


def create_table():
    """
    Creates table if table doesn't exist
    """

    if StudioVisualisationLogs.exists():
        raise OperationNotPerformedError("Table already exists")
    StudioVisualisationLogs.create_table(
        read_capacity_units=credentials.DYNAMO_GENERIC_RW_CAP,
        write_capacity_units=credentials.DYNAMO_GENERIC_RW_CAP)


def create_chart_logs_request(studio_viz_id,
                              timestamp,
                              status,
                              chart_url,
                              message=None):
    """
    Creates a charts logs request using studio_viz_id
    has hash key and (timestamp+chartname) as a range
    key

    Parameters
    ----------
    studio_viz_id : String
        Unique studio visualisation request id
    status : String
        Status of charts for this job
    chart_url : string
        Chart relative url
    message: string
        error message if any
    timestamp: string
        timestamp when chart was created
    """

    chart_logs_request = StudioVisualisationLogs(chart_url=chart_url,
                                                 timestamp=timestamp,
                                                 status=status,
                                                 studio_viz_id=studio_viz_id,
                                                 message=message)

    save_dynamo_object(chart_logs_request)


def get_chart_logs_data(studio_viz_id, timestamp):
    """
    Returns the pynamo object containing chart info

    Parameters
    ----------
    studio_viz_id : String
        Unique studio visualisation request id
    timstamp: string
        string containing timestamp + chart_name

    Returns
    -------
    chart_object: pynamo object
        contains chart relative urls and status
    """

    chart_logs_object = StudioVisualisationLogs.get(str(studio_viz_id),
                                                    str(timestamp))
    return chart_logs_object


def as_dict(chart_query):
    """
    Return dictionary object of dynamodb
    attributes

    Parameters
    ----------
    chart_query : pynamo object
        pynamo object of studio visualisation logs dynamodb

    """
    return {
        'status': chart_query.status,
        'message': chart_query.message,
        'timestamp': chart_query.timestamp,
        'chart_url': chart_query.chart_url,
        'studio-viz-id': chart_query.studio_viz_id
    }
